@@ -21,7 +21,9 @@
 #include "security8021xsetting.h"
 #include "security8021xsetting_p.h"
 
+#if !NM_CHECK_VERSION(1, 0, 0)
 #include <nm-setting-8021x.h>
+#endif
 
 #include <QtCore/QDebug>
 
@@ -619,7 +621,7 @@ void NetworkManager::Security8021xSetting::fromMap(const QVariantMap &setting)
     if (setting.contains(QLatin1String(NM_SETTING_802_1X_EAP))) {
         const QStringList methods = setting.value(QLatin1String(NM_SETTING_802_1X_EAP)).toStringList();
         QList<EapMethod> eapMethods;
-        foreach (const QString & method, methods) {
+        Q_FOREACH (const QString & method, methods) {
             if (method == "leap") {
                 eapMethods << EapMethodLeap;
             } else if (method == "md5") {
@@ -822,7 +824,7 @@ QVariantMap NetworkManager::Security8021xSetting::toMap() const
     if (!eapMethods().isEmpty()) {
         QStringList methods;
 
-        foreach (const EapMethod & method, eapMethods()) {
+        Q_FOREACH (const EapMethod & method, eapMethods()) {
             if (method == EapMethodLeap) {
                 methods << "leap";
             } else if (method == EapMethodMd5) {
